@@ -1,7 +1,7 @@
 package DBGp::Client::AnyEvent;
 
 use strict;
-use warning;
+use warnings;
 
 =head1 NAME
 
@@ -36,7 +36,7 @@ A thin L<AnyEvent> wrapper on top of L<DBGp::Client>.
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 1;
 
